@@ -25,8 +25,8 @@ import os
 from pathlib import Path
 import shutil
 import sys
-from beetools.beemsg import ok as msg_ok, error as msg_error
-from beetools import Archiver
+# from beetools.beemsg import ok as msg_ok, error as msg_error
+from beetools.beearchiver import Archiver, msg_ok, msg_error
 
 _PROJ_DESC = __doc__.split('\n')[0]
 _PROJ_PATH = Path(__file__)
@@ -573,7 +573,7 @@ def do_examples(p_app_path=None, p_cls=True):
     success = example_tools()
     b_tls.print_footer()
     if success:
-        return b_tls.archive_pth
+        return b_tls.arc_pth
     return False
 
 
