@@ -1,20 +1,20 @@
 
 '''Tools for Bright Edge eServices developments & projects
 
-These tools was designed for the use in the Bright Edge eServices echo system.
+These tools are designed for the use in the Bright Edge eServices echo system.
 It defines methods and functions for general use purposes and standardization
 in the Bright Edge eServices echo system.
 
-The module define defaults for log levels, display on console, operating
+The module define defaults for log levels, console display, operating
 system names and date formats.
 
-The defaults are used in this module and across the Bright Edge eServices
-echo system.  The module basically has
+This module and the Bright Edge eServices echo systemuses these defaults,
+which can be changed by latering the parameters.
 
 To Do
 =====
-1.  Better example on the logging integration
-2.  Complete doctests for all methods & functions
+1. Better example on the logging integration
+2. Complete doctests for all methods & functions
 
 '''
 
@@ -92,7 +92,7 @@ def get_dir(p_venv_root_dir, p_name_pref) -> Path:
     return p_venv_root_dir / Path('{}_env'.format(p_name_pref))
 
 
-def install_in(p_venv_root_dir, p_venv_name, p_instructions, p_verbose=True):
+def install_in(p_venv_root_dir, p_venv_name, p_instructions, p_crash = True, p_verbose=True):
     '''Execute (install) commands in a virtual environment
 
     Parameters
@@ -146,7 +146,7 @@ def install_in(p_venv_root_dir, p_venv_name, p_instructions, p_verbose=True):
         script_cmds.append('_EOF_')
         script_cmds.append('exit')
     ret_code = beescript.exec_batch_in_session(
-        script_cmds, p_script_name=script_name, p_verbose=p_verbose, p_switches=switches
+        script_cmds, p_script_name=script_name, p_verbose=p_verbose, p_switches=switches, p_crash = p_crash
     )
     return ret_code
 
